@@ -1,9 +1,12 @@
 <?php
 
+use MediaWiki\Extension\Math\MathMathML;
+use MediaWiki\Extension\Math\MathRenderer;
+
 /**
  * Test the database access and core functionality of MathRenderer.
  *
- * @covers \MathRenderer
+ * @covers \MediaWiki\Extension\Math\MathRenderer
  *
  * @group Math
  * @group Database
@@ -30,17 +33,17 @@ class MathDatabaseTest extends MediaWikiTestCase {
 	 * }
 	 * was not sufficient.
 	 */
-	protected function setUp() : void {
+	protected function setUp(): void {
 		parent::setUp();
 		// TODO: figure out why this is necessary
-		$this->db = wfGetDB( DB_MASTER );
+		$this->db = wfGetDB( DB_PRIMARY );
 		$this->renderer = new MathMathML( self::SOME_TEX );
 		$this->tablesUsed[] = 'mathoid';
 	}
 
 	/**
 	 * Checks the tex and hash functions
-	 * @covers \MathRenderer::getInputHash
+	 * @covers \MediaWiki\Extension\Math\MathRenderer::getInputHash
 	 */
 	public function testInputHash() {
 		$expectedhash = $this->db->encodeBlob( pack( "H32", md5( self::SOME_TEX ) ) );
@@ -58,8 +61,8 @@ class MathDatabaseTest extends MediaWikiTestCase {
 
 	/**
 	 * Checks database access. Writes an entry and reads it back.
-	 * @covers \MathRenderer::writeToDatabase
-	 * @covers \MathRenderer::readFromDatabase
+	 * @covers \MediaWiki\Extension\Math\MathRenderer::writeToDatabase
+	 * @covers \MediaWiki\Extension\Math\MathRenderer::readFromDatabase
 	 */
 	public function testDBBasics() {
 		$this->setValues();
@@ -80,7 +83,7 @@ class MathDatabaseTest extends MediaWikiTestCase {
 
 	/**
 	 * Checks the creation of the math table.
-	 * @covers \MathHooks::onLoadExtensionSchemaUpdates
+	 * @covers \MediaWiki\Extension\Math\Hooks::onLoadExtensionSchemaUpdates
 	 */
 	public function testCreateTable() {
 		$this->setMwGlobals( 'wgMathValidModes', [ 'mathml' ] );
@@ -95,7 +98,7 @@ class MathDatabaseTest extends MediaWikiTestCase {
 		$this->assertCount( 16, $row );
 	}
 
-	/*
+	/**
 	 * This test checks if no additional write operation
 	 * is performed, if the entry already existed in the database.
 	 */
