@@ -1,7 +1,5 @@
 <?php
 
-use MediaWiki\Extension\Math\MathRenderer;
-
 /**
  * Test the Id feature
  *
@@ -11,14 +9,16 @@ use MediaWiki\Extension\Math\MathRenderer;
  *
  * @license GPL-2.0-or-later
  */
-class MathIdTest extends MediaWikiTestCase {
+class MathIdTest extends MediaWikiIntegrationTestCase {
 
 	/**
 	 * Checks if the id specified as attribute is set in the renderer object
 	 */
 	public function testBasics() {
 		define( 'RANDOM_ID', 'a_random_id' );
-		$renderer = MathRenderer::getRenderer( "a+b", [ 'id' => RANDOM_ID ] );
+		$renderer = $this->getServiceContainer()
+			->get( 'Math.RendererFactory' )
+			->getRenderer( "a+b", [ 'id' => RANDOM_ID ] );
 		$this->assertEquals( RANDOM_ID, $renderer->getID() );
 	}
 
